import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import styled from "styled-components";
import SectionContainer from "./SectionContainer";
import Button from "./Button";
import { faPen, faTable, faTrash } from "@fortawesome/free-solid-svg-icons";
import info from "./../mocks/table.json";
import { cls } from "../lib/utils";
import usePagination from "../hooks/usePagination";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
export default function Table() {
    const { options, itemPages, rows, handleChangeItemsPerPage } = usePagination({
        rows: info,
        options: [5, 10, 20, 50, 100],
    });
    return (_jsxs(SectionContainer, { classWrapper: "w-full", classContainer: "flex flex-col gap-3", children: [_jsx(TableHeader, { onChangeItemsPerPage: handleChangeItemsPerPage, options: options }), _jsxs("table", { className: "w-full text-center", children: [_jsx(Thead, { children: _jsxs("tr", { children: [_jsx("th", { children: "ID" }), _jsx("th", { children: "Column 2" }), _jsx("th", { children: "Column 3" }), _jsx("th", { children: "Action" })] }) }), _jsx(Tbody, { children: rows.map((item) => (_jsx(Row, { ...item }, item.id))) })] }), _jsx(TableFooter, { items: itemPages })] }));
}
const Thead = styled.thead `
    & th {
        --rounded: 0.5rem;
        padding: 0.5rem;
        background: var(--c3-bg);
    }
    & th:first-child {
        border-radius: var(--rounded) 0 0 var(--rounded);
    }
    & th:last-child {
        border-radius: 0 var(--rounded) var(--rounded) 0;
    }
`;
const Tbody = styled.tbody `
    & td {
        --rounded: 0.5rem;
        padding: 0.5rem;
    }
    & tr {
        transition: background 0.2s ease;
    }
    & tr:nth-child(even) {
        background: rgba(0, 0, 0, 0.03);
    }
    & tr:hover {
        background: rgba(0, 0, 0, 0.05);
        transition: background 0.2s ease;
    }
    & td:first-child {
        border-radius: var(--rounded) 0 0 var(--rounded);
    }
    & td:last-child {
        border-radius: 0 var(--rounded) var(--rounded) 0;
    }
`;
function TableHeader({ onChangeItemsPerPage, options = [5] }) {
    return (_jsxs("div", { className: "flex justify-between items-center", children: [_jsxs("div", { className: "flex items-center gap-1 text-[--c1-bg]", children: [_jsx(FontAwesomeIcon, { icon: faTable }), _jsx("h4", { className: "text-xl font-mono font-bold", children: "Datos" })] }), _jsxs("div", { className: "flex items-center gap-2", children: [_jsx("span", { className: "text-[--c3-txt] text-base font-bold", children: "Items por pagina:" }), _jsx("select", { onChange: onChangeItemsPerPage, className: "outline-none rounded-md px-2 py-1", children: options.map((item) => (_jsx("option", { value: item, children: item }, item))) })] })] }));
}
function TableFooter({ items }) {
    return (_jsx("div", { className: "flex justify-center gap-2", children: items.map((item) => (_jsx(PaginationButton, { theme: item.selected ? "info" : "transparent", ...item }, item.id))) }));
}
function PaginationButton({ disabled = false, ...props }) {
    return (_jsx(Button, { classWrapper: cls("aspect-square w-6 h-6", {
            "opacity-50": disabled,
        }), classPseudo: cls({
            hidden: disabled,
        }), disabled: disabled, theme: "transparent", scaleHover: false, ...props }));
}
function Row({ ...item }) {
    return (_jsxs("tr", { children: [_jsx("td", { children: item.id }), _jsx("td", { children: item.name }), _jsx("td", { children: item.email }), _jsx("td", { children: _jsxs("div", { className: "flex justify-center gap-1", children: [_jsx(Button, { icon: faPen, small: true }), _jsx(Button, { icon: faTrash, small: true, theme: "danger" })] }) })] }));
}
